@@ -1,14 +1,16 @@
+#' @export
 "print.HOF.list" <-  function (
-		x, 
-		test = 'AICc',  
-		selectMethod = 'bootselect', 
+		x,
+		test = 'AICc',
+		selectMethod = 'bootselect',
 		...) {
 	if(selectMethod == 'bootselect' & is.null(x[[1]]$bootstrapmodels)) {
 		message('Bootstrap results missing. Using selectMethod "pick.model" instead.\n')
 		selectMethod <- 'pick.model'
 	}
     cat("Deviances:\n")
-    printCoefmat(sapply(x, deviance), na.print="", has.Pvalue=FALSE, ...)
+    sapply(sapply(x, function(m) m$models), '[[', 'deviance')
+    printCoefmat(sapply(x, function(x) deviance(x)), na.print="", has.Pvalue=FALSE, ...)
     cat(paste("\nSuggested best models (",test, ", ", selectMethod, "):", sep=''))
     tmp <- sapply(x, pick.model, test=test, selectMethod = selectMethod, silent = TRUE, ...)
     names(tmp) <- names(x)
