@@ -22,7 +22,7 @@ obs <- tv.obs(db)
 # write.csv2(taxa, file='taxonnames.csv')
 taxa <- tax('all') # read.csv('taxonnames.csv')
 names(veg) <- sub('.0', '', names(veg), fixed=TRUE)
-# for(i in 1:ncol(veg)) names(veg)[i] <- as.character(taxa$LETTERCODE[match(as.numeric(names(veg)[i]), taxa$TaxonUsageID)])
+names(veg) <- taxa$LETTERCODE[match(names(veg), taxa$TaxonUsageID)]
 
 ## ----5veg.2, results='hide'---------------------------------------------------
 veg.sqrt <- tv.veg(db, cover.transform='sqrt', tax=FALSE, spcnames='Numbers')
@@ -57,11 +57,13 @@ plot(mods.sq)
 mods.pa <- HOF(veg.pa, site$MGL, M=1, bootstrap=NULL)
 plot(mods.pa)
 
-## ----paraplot, warning=FALSE, out.width='.5\\textwidth'-----------------------
-plot(mods.pa[['RNNCPEP']], para=TRUE, onlybest=FALSE)
+## ----paraplot, eval = TRUE, warning=FALSE, out.width='.5\\textwidth'----------
+lRP <- taxa$LETTERCODE[taxa$TaxonName == 'Ranunculus repens']
+Para(mods.pa[[lRP]])
+plot(mods.pa[[lRP]], para=TRUE, onlybest=FALSE)
 
-## ----sqrt-ELYMREP, results='hide', warning=FALSE, out.width='.5\\textwidth'----
-mod.sqrt <- HOF(veg.sqrt$RNNCPEP, site$MGL, M=10, family=poisson, bootstrap = 10)
+## ----sqrt-2, results='hide', warning=FALSE, out.width='.5\\textwidth'---------
+mod.sqrt <- eHOF:::HOF.default(veg.sqrt[[lRP]], site$MGL, M=10, family=poisson, bootstrap = 10)
 plot(mod.sqrt, marginal='point', para=TRUE, onlybest=FALSE, newdata=seq(min(mod.sqrt$range), max(mod.sqrt$range), length.out=10000) )
 Para(mod.sqrt)
 
